/*!
 * @file   head file apxa_interface.h
 * @brief  user interface class,for second development use
 * @Author yuko@antenna.co.jp
 * @date   2016.07.01
 * @copyright Antenna House.Inc.  All Rights Reserved
 */


#ifndef  _APXA__INTERFACE_H
#define  _APXA__INTERFACE_H

#include <map>
#include <AHCommon/AHString.h>
#include <AHCommon/AHCustomStream.h>

#ifdef __cplusplus
extern "C" {            /* Assume C declarations for C++ */
#endif  /* __cplusplus */


#ifndef SYSBOOL
#ifdef bool
#undef bool
#endif
#endif

#pragma warning(disable:4251)

#ifdef AH_WIN_MSC_
#ifdef APXA_ANALYZER_EXPORTS
#define APXA_API __declspec(dllexport)
#else
#define APXA_API __declspec(dllimport)
#endif
#else
        #define APXA_API
#endif

namespace APXA_ANALYZER {

    using namespace AHCommonNS;
    using namespace std;

    enum APXA_ERROR {
        APXA_SUCCESS = 0,
        APXA_OPEN_ERROR,      /*! @brief  DOCUMENT File open errors */
        APXA_PASSWORD_ERROR,
        APXA_READ_ERROR,      /*! @brief  PDF File read errors */
        APXA_PAGE_ERROR,      /*! @brief  Page processing errors */
        APXA_SECTION_ERROR,   /*! @brief  Section processing errors */
        APXA_FRAME_ERROR,     /*! @brief  frame processing errors */
        APXA_PARAGRAPH_ERROR, /*! @brief  Paragraph processing errors */
        APXA_TEXTLINE_ERROR,  /*! @brief  Text Line processing errors */
        APXA_TEXT_ERROR,      /*! @brief  Text processing errors */
        APXA_CELL_ERROR,      /*! @brief  Font processing errors */
        APXA_GRAPHIC_ERROR,   /*! @brief  Graphic processing errors */
        APXA_TABLE_ERROR,     /*! @brief  Table processing errors */
        APXA_ROW_ERROR,       /*! @brief  Row processing errors */
        APXA_SVG_ERROR,       /*! @brief  SVG processing errors */
        APXA_WRITE_ERROR,     /*! @brief  DOCUMENT File write errors */
        APXA_OUTFOLDER_ERROR, /*! @brief  OutFolder errors */
        APXA_LICENSE_ERROR,   /*! @brief  license errors */
        APXA_OTHER_ERROR,     /*! @brief  Other processing errors */
    };

    /*! @brief ϊ */

    const int APXA_OPT_ONECHAR              = 0x00000001;  /*! @brief  1Âo */
    const int APXA_OPT_CIDOUTPUT            = 0x00000002;  /*! @brief  CIDo͂ */
    const int APXA_OPT_TABLE_NOT_PUT        = 0x00000008;  /*! @brief  e[uo͂Ȃ */
    const int APXA_OPT_ALL_TEXT_IS_SHAPE    = 0x00000010;  /*! @brief  ׂăeLXg{bNXgŏo */
    const int APXA_OPT_RESERVED_1           = 0x00000020;  /*! @brief  \1  */
    const int APXA_OPT_UNDERLINEOUT         = 0x00000040;  /*! @brief  o */
    const int APXA_OPT_PICTURENOTOUT        = 0x00000080;  /*! @brief  摜o͂Ȃ */
    const int APXA_OPT_PARANOTCREATEINCELL  = 0x00000100;  /*! @brief  e[u̒ł͒i쐬Ȃ */
    const int APXA_OPT_NOTTEXTSVG           = 0x00000200;  /*! @brief  SVGɃeLXgo͂Ȃ */
    const int APXA_OPT_NOTIMAGESVG          = 0x00000400;  /*! @brief  NbsOt摜SVGɕϊȂ */
    const int APXA_CONVERT_EMF              = 0x00000800;  /*! @brief  EMFɏo͂ */
    const int APXA_OPT_RESERVED_2           = 0x00001000;  /*! @brief  \2  */
    const int APXA_OPT_ORIGINAL_CHAR_ROTATE = 0x00002000;  /*! @brief  ̉̕]pxo */
    const int APXA_OPT_ORIGINAL_IMAGE_OUT   = 0x00004000;  /*! @brief  C[WɊ܂܂ĂIWi摜o͂ ̏w肳Ȃꍇ͐C[WɊ܂܂ĂIWi摜͏o͂Ȃ */

    enum PWDTYPE{
        PWD_NOPASSWORD,               
        PWD_USERPASSWORD,              
        PWD_OWNERPASSWORD,             
        PWD_ProtectedByPassWord                    
    };

    enum OPTMODE{
        ALL_PAGE_CONV,
        BGN_END_CONV,    // eg:1--10
        SELECT_PAGE_CONV // eg:1,3,5...
    };

    /*! @brief [JtHg */ 
    struct LOCFONT {
        /*!
         * @brief LOCFONT RXgN^
         * @param void
         * @date  2016.07.01
         * @return void
         */
        LOCFONT():charset(-1), style(0), alias_Italic(false), italic(false),
        weight(0), alias_Weight(0), tmPitchAndFamily(0) { }
        /*!
         * @brief LOCFONT init function
         * @param void
         * @date  2016.07.01
         * @return void
         */
        void Init(void) {
            *this = LOCFONT();
        }
        AHString    FullName;         /*! @brief  font full name */
        AHString    FamilyName;       /*! @brief  font family name */
        int         charset;          /*! @brief  font char set,for example Japan(128) */
        int         style;            /*! @brief  font property,0 regular 1 bold 2 italic 3 bold&italic */
        bool        alias_Italic;     /*! @brief  italic mark */
        bool        italic;           /*! @brief  italic mark */
        int         weight;           /*! @brief  font weight,usually to use whether or not bold */
        int         alias_Weight;     /*! @brief  font weight,usually to use whether or not bold */
        int         tmPitchAndFamily; /*! @brief  font pitch and family value, flat mark */
        AHString    LocalFamilyName;  /*! @brief  font local family name */
        AHString    PostscripName;    /*! @brief  font post script name */
    };

    /*! @brief [JtHg}bviID, [JtHg) */
    typedef map<int, LOCFONT*>      LocFontMap;
    typedef LocFontMap::iterator    LocFontMapIt;

    class CAPXA_Analyzer;

    class APXA_API APXA_Converter //
    {
    public:
        /**
         * @brief    RXgN^
         */
         APXA_Converter();
        /**
         * @brief    fXgN^
         */
         ~APXA_Converter();

    public: 
        /**
         * @brief   PDFt@C̃pX[hw肵܂B
         * @param   password: pX[h
         * @return  APXA_ERROR
         */
         APXA_ERROR APXA_SetPassword(AHString password);
     
        /**
         * @brief   o̓t@C̃x[Xݒ肵܂B
         * @param   baseName: o̓t@C̃x[X
         * @return  void
         */
         void APXA_SetBaseName(AHString baseName);

        /**
         * @brief   o̓tH_ݒ肵܂B
         * @param   outFolder: o̓tH_
         * @return  void
         */
         void APXA_SetOutFolder(AHString outFolder);

        /**
         * @brief   ݒt@Cݒ肵܂B
         * @param   settingFile: ݒt@C
         * @return  void
         */
         void  APXA_SetSettingFile(AHString settingFile);

        /**
         * @brief   ϊݒ肵܂B
         * @param   option: ϊ
         * @return  void
         */
         void  APXA_SetConversionOption(int option);

        /**
         * @brief    y[W擾܂
         * @param    controller:PDFXg[  Javap
         * @return   y[W
         */
         int APXA_GetPageCount(AHCustomStreamController *controller);

         /**
         * @brief    y[W擾܂
         * @param    inputStream:PDFXg[
         * @return   y[W
         */
         int APXA_GetPageCount(std::istream *inputStream);

        /**
         * @brief   ϊ擪y[W̔ԍݒ肵܂B
         * @param    pageNo:  y[Wԍ
         * @return   void
         */
         void APXA_SetStartPage(int pageNo);
     
        /**
         * @brief   ϊŏIy[W̔ԍݒ肵܂B
         * @param   pageNo:  y[Wԍ
         * @return  void
         */
         void APXA_SetEndPage(int pageNo);
#if 0
        /**
         * @brief   ϊy[W̔ԍݒ肵܂B
         * @param   pageNoSetting:  y[Wԍw  w (1-10  ܂ 1,3,5)
         * @return  APXA_ERROR
         */
         APXA_ERROR APXA_SetConvertPage(vector<int> pageNoVec, OPTMODE optionMode);
#endif
        /**
         * @brief     AHPDFXML֕ϊ
         * @param     controller:PDFXg[  Javap
         * @return    APXA_ERROR
         */
         APXA_ERROR APXA_Convert(AHCustomStreamController *controller);

        /**
         * @brief     AHPDFXML֕ϊ
         * @param     inputStream:PDFXg[
         * @return    APXA_ERROR
         */
         APXA_ERROR APXA_Convert(std::istream *inputStream);

         /**
         * @brief     CZXG[ڍ׃R[h擾
         * @param     void
         * @return    CZXG[ڍ׃R[h
         */
         int APXA_GetLicenseErrorCode();

         /**
         * @brief     v_Nĝ擾
         * @param     void
         * @return    v_Ng
         */
         const char *APXA_GetProductName();

         /**
         * @brief     [Xԍ擾
         * @param     void
         * @return    [Xԍ
         */
         const char *APXA_GetReleaseNo();

         /**
         * @brief     vbgtH[擾
         * @param     void
         * @return    vbgtH[
         */
         const char *APXA_GetPlatform();

         /**
         * @brief     Rs[Cg擾
         * @param     void
         * @return    Rs[Cg
         */
         const char *APXA_GetCopyright();

     private:
         CAPXA_Analyzer *m_pAnalyzer;
    };
}

#ifdef __cplusplus
}
#endif  /* __cplusplus */

#endif

